@@ -3,7 +3,7 @@ package IO::Multiplex;
 use strict;
 use warnings;
 
-our $VERSION = '1.15';
+our $VERSION = '1.16';
 
 =head1 NAME
 
@@ -932,10 +932,7 @@ sub close
 
     delete $self->{_fhs}{"$fh"};
     delete $self->{_handles}{"$fh"};
-    if (my $x = tied $fh) {
-        undef $x;
-        untie *$fh;
-    }
+    untie *$fh;
     close $fh;
     $obj->mux_close($self, $fh) if $obj && $obj->can("mux_close");
 }
@@ -1026,6 +1023,8 @@ sub FETCH
     return "Fnord";
 }
 
+sub UNTIE {}
+
 1;
 
 __END__
@@ -1109,6 +1108,6 @@ Copyright 2001-2008 Rob Brown <bbb@cpan.org>
 
 Released under the same terms as Perl itself.
 
-$Id: Multiplex.pm,v 1.42 2015/03/31 18:24:50 rob Exp $
+$Id: Multiplex.pm,v 1.45 2015/04/09 21:27:54 rob Exp $
 
 =cut
